@@ -59,8 +59,11 @@ def _get_parser():
     parser.add_argument('--pre_announce', action='store_true', dest='pre_announce',
                         help="Announce the name of each test before it runs. This "
                              "can help track down a hanging test. This automatically sets -n 1.")
-    parser.add_argument('-f', '--fail', action='store_true', dest='save_fails',
+    parser.add_argument('-f', action='store_true', dest='save_fails',
                         help="Save failed tests to failtests.in file.")
+    parser.add_argument('--fail', action='store', dest='failfile',
+                        metavar='FILE',
+                        help='Path to a file containing testspecs of failed tests.')
     parser.add_argument('--full_path', action='store_true', dest='full_path',
                         help="Display full test specs instead of shortened names.")
     parser.add_argument('-i', '--isolated', action='store_true', dest='isolated',
@@ -391,12 +394,7 @@ def get_module(fname):
             else:
                 raise ImportError("can't import %s" % modpath)
 
-    start_coverage()
-
-    try:
-        mod = try_import(fname, modpath)
-    finally:
-        stop_coverage()
+    mod = try_import(fname, modpath)
 
     return fname, mod
 
